"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel
from typing_extensions import TypedDict


class GiftCardTransactionCreateTypedDict(TypedDict):
    r"""Create a charge against a gift card"""

    number: str
    r"""The 16-19 digit number for the gift card."""
    pin: str
    r"""The PIN for this gift card."""
    amount: int
    r"""The monetary amount for this transaction to charge against the gift card, in the smallest currency unit (for example, cents or pence)."""


class GiftCardTransactionCreate(BaseModel):
    r"""Create a charge against a gift card"""

    number: str
    r"""The 16-19 digit number for the gift card."""

    pin: str
    r"""The PIN for this gift card."""

    amount: int
    r"""The monetary amount for this transaction to charge against the gift card, in the smallest currency unit (for example, cents or pence)."""
